@@ -261,6 +261,8 @@ static void bp_volume_changed_callback (GstElement *playbin, GParamSpec *spec, B
 
     g_object_get (G_OBJECT (playbin), "volume", &volume, NULL);
 
+    player->current_volume = volume;
+
     if (player->volume_changed_cb != NULL) {
         player->volume_changed_cb (player, volume);
     }
@@ -287,15 +289,6 @@ _bp_pipeline_construct (BansheePlayer *player)
     // source and decoder elements) based on source URI and stream content
     player->playbin = gst_element_factory_make ("playbin2", "playbin");
 
-    player->supports_stream_volume = FALSE;
-#if BANSHEE_CHECK_GST_VERSION(0,10,25)
-    player->supports_stream_volume = gst_element_implements_interface (
-        player->playbin, GST_TYPE_STREAM_VOLUME);
-#endif
-
-    bp_debug ("Stream volume supported: %s",
-        player->supports_stream_volume ? "YES" : "NO");
-
 #ifdef ENABLE_GAPLESS
     // FIXME: Connect a proxy about-to-finish callback that will generate a next-track-starting callback.
     // This can be removed once playbin2 generates its own next-track signal.
@@ -327,6 +320,16 @@ _bp_pipeline_construct (BansheePlayer *player)
     
     g_return_val_if_fail (audiosink != NULL, FALSE);
 
+    // Set the profile to "music and movies" (gst-plugins-good 0.10.3)
+    if (g_object_class_find_property (G_OBJECT_GET_CLASS (audiosink), "profile")) {
+        g_object_set (G_OBJECT (audiosink), "profile", 1, NULL);
+    }
+
+    /* Set the audio sink to READY so it can autodetect the right sink element
+     * if needed, as this allows us to correctly determine whether it has a
+     * volume */
+    gst_element_set_state (audiosink, GST_STATE_READY);
+
     // See if the audiosink has a 'volume' property.  If it does, we assume it saves and restores
     // its volume information - and that we shouldn't
     player->audiosink_has_volume = FALSE;
@@ -342,10 +345,6 @@ _bp_pipeline_construct (BansheePlayer *player)
     bp_debug ("Audiosink has volume: %s",
         player->audiosink_has_volume ? "YES" : "NO");
         
-    // Set the profile to "music and movies" (gst-plugins-good 0.10.3)
-    if (g_object_class_find_property (G_OBJECT_GET_CLASS (audiosink), "profile")) {
-        g_object_set (G_OBJECT (audiosink), "profile", 1, NULL);
-    }
     
     // Create a custom audio sink bin that will hold the real primary sink
     player->audiobin = gst_bin_new ("audiobin");
@@ -392,7 +391,7 @@ _bp_pipeline_construct (BansheePlayer *player)
         gst_element_link_many (audiosinkqueue, player->volume, audiosink, NULL);
     }
     player->before_rgvolume = player->volume;
-    player->after_rgvolume = audiosink;
+    player->after_rgvolume = player->audiosink = audiosink;
     player->rgvolume_in_pipeline = FALSE;
     _bp_replaygain_pipeline_rebuild (player);
 
@@ -431,6 +430,12 @@ _bp_pipeline_destroy (BansheePlayer *player)
     if (GST_IS_ELEMENT (player->playbin)) {
         player->target_state = GST_STATE_NULL;
         gst_element_set_state (player->playbin, GST_STATE_NULL);
+
+        // The audiosink was set READY early to detect sink volume control in
+        // case it is out of sync with the playbin state ensure it's in NULL now
+        if (player->audiosink != NULL && GST_STATE (player->audiosink) != GST_STATE_NULL)
+          gst_element_set_state (player->audiosink, GST_STATE_NULL);
+
         gst_object_unref (GST_OBJECT (player->playbin));
     }
     
