@@ -2,8 +2,8 @@ using System;
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: ApplicationVersion ("2.2.0", "2.2")]
-[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2011-09-19 21:54:32 CEST")]
+[assembly: ApplicationVersion ("2.2.1", "2.2.1")]
+[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2011-11-01 21:51:08 CET")]
 
 [assembly: AssemblyVersion ("2.2.0.0")]
 [assembly: AssemblyTitle ("Banshee")]
