@@ -33,10 +33,12 @@ using System.Net;
 using System.Web;
 using System.Collections.Generic;
 
+using Hyena;
+
 using Banshee.Base;
 
 namespace Banshee.Playlists.Formats
-{   
+{
     public class PlaylistParser
     {
         private static PlaylistFormatDescription [] playlist_formats = new PlaylistFormatDescription [] {
@@ -46,15 +48,21 @@ namespace Banshee.Playlists.Formats
             AsfReferencePlaylistFormat.FormatDescription,
             XspfPlaylistFormat.FormatDescription
         };
-        
+
         private List<Dictionary<string, object>> elements;
-        private Uri base_uri = new Uri (Environment.CurrentDirectory);
+        private Uri base_uri = null;
         private string title = null;
-        
+
         public PlaylistParser ()
         {
+            if (Environment.CurrentDirectory.Equals ("/")) {
+                // System.Uri doesn't like / as a value
+                base_uri = new Uri ("file:///");
+            } else {
+                base_uri = new Uri (Environment.CurrentDirectory);
+            }
         }
-        
+
         public bool Parse (SafeUri uri)
         {
             ThreadAssist.AssertNotInMainThread ();
@@ -65,7 +73,7 @@ namespace Banshee.Playlists.Formats
                 Stream web_stream = null;
                 bool partial_read = false;
                 long saved_position = 0;
-                
+
                 if (uri.Scheme == "file") {
                     stream = Banshee.IO.File.OpenRead (uri);
                 } else if (uri.Scheme == "http") {
@@ -89,10 +97,10 @@ namespace Banshee.Playlists.Formats
                         }
                         request.Credentials = new NetworkCredential (username, password);
                     }
-            
+
                     response = (HttpWebResponse)request.GetResponse ();
                     web_stream = response.GetResponseStream ();
-                    
+
                     try {
                         stream = new MemoryStream ();
 
@@ -108,7 +116,7 @@ namespace Banshee.Playlists.Formats
                             stream.Write (buffer, 0, read);
                             saved_position = stream.Position;
                         }
-                        
+
                         stream.Position = 0;
                     } finally {
                         if (!partial_read) {
@@ -120,20 +128,23 @@ namespace Banshee.Playlists.Formats
                     Hyena.Log.DebugFormat ("Not able to parse playlist at {0}", uri);
                     return false;
                 }
-                                  
+
                 PlaylistFormatDescription matching_format = null;
 
                 foreach (PlaylistFormatDescription format in playlist_formats) {
                     stream.Position = 0;
-                    
-                    StreamReader reader = new StreamReader (stream);
-                    if (format.MagicHandler (reader)) {
+
+                    if (format.MagicHandler (new StreamReader (stream))) {
                         matching_format = format;
                         break;
                     }
                 }
 
                 if (matching_format == null) {
+                    if (partial_read) {
+                        web_stream.Close ();
+                        response.Close ();
+                    }
                     return false;
                 }
 
@@ -151,22 +162,22 @@ namespace Banshee.Playlists.Formats
                 playlist.BaseUri = BaseUri;
                 playlist.Load (stream, false);
                 stream.Dispose ();
-                
+
                 elements = playlist.Elements;
                 Title = playlist.Title ?? Path.GetFileNameWithoutExtension (uri.LocalPath);
                 return true;
             }
         }
-        
+
         public List<Dictionary<string, object>> Elements {
             get { return elements; }
         }
-        
+
         public Uri BaseUri {
             get { return base_uri; }
             set { base_uri = value; }
         }
-        
+
         public string Title {
             get { return title; }
             set { title = value; }
