@@ -34,6 +34,8 @@ using Mono.Unix;
 using Gtk;
 using Gdk;
 
+using Hyena.Gui;
+
 using Banshee.Sources;
 using Banshee.Library;
 using Banshee.ServiceStack;
@@ -49,34 +51,34 @@ namespace Banshee.Sources.Gui
         private static TargetEntry [] dnd_source_entries = new TargetEntry [] {
             Banshee.Gui.DragDrop.DragDropTarget.Source
         };
-            
+
         private static TargetEntry [] dnd_dest_entries = new TargetEntry [] {
             Banshee.Gui.DragDrop.DragDropTarget.Source,
             Hyena.Data.Gui.ListViewDragDropTarget.ModelSelection,
             Banshee.Gui.DragDrop.DragDropTarget.UriList
         };
-        
+
         private Source new_playlist_source = null;
         private TreeIter new_playlist_iter = TreeIter.Zero;
         private bool new_playlist_visible = false;
-        
+
         private Source final_drag_source = null;
         private uint final_drag_start_time = 0;
-        
+
         private void ConfigureDragAndDrop ()
         {
             EnableModelDragSource (Gdk.ModifierType.Button1Mask | Gdk.ModifierType.Button3Mask,
                 dnd_source_entries, DragAction.Copy | DragAction.Move);
-        
+
             EnableModelDragDest (dnd_dest_entries, DragAction.Copy | DragAction.Copy);
         }
-        
+
         protected override bool OnDragMotion (Gdk.DragContext context, int x, int y, uint time)
         {
             TreePath path;
             TreeViewDropPosition pos;
             Source active_source = ServiceManager.SourceManager.ActiveSource;
-            
+
             if (active_source.SupportedMergeTypes == SourceMergeType.None) {
                 Gdk.Drag.Status (context, 0, time);
                 return false;
@@ -84,7 +86,7 @@ namespace Banshee.Sources.Gui
                 Gdk.Drag.Status (context, 0, time);
                 return false;
             }
-            
+
             Source drop_source = store.GetSource (path);
             Source parent_source = (drop_source as LibrarySource) ?? (drop_source.Parent as LibrarySource);
 
@@ -105,7 +107,7 @@ namespace Banshee.Sources.Gui
 
             bool move = (active_source is LibrarySource) && (drop_source is LibrarySource);
             Gdk.Drag.Status (context, move ? Gdk.DragAction.Move : Gdk.DragAction.Copy, time);
-            
+
             return true;
         }
 
@@ -119,7 +121,7 @@ namespace Banshee.Sources.Gui
                 else
                     HideNewPlaylistRow ();
             }
-            
+
             if (parent == null || active == null) {
                 return;
             }
@@ -132,9 +134,10 @@ namespace Banshee.Sources.Gui
 
             TreeIter parent_iter = store.FindSource (parent);
             new_playlist_iter = store.AppendNode (parent_iter);
-            
+
             store.SetValue (new_playlist_iter, 0, NewPlaylistSource);
             store.SetValue (new_playlist_iter, 1, 999);
+            store.SetValue (new_playlist_iter, 2, SourceModel.EntryType.Source);
             new_playlist_visible = true;
 
             UpdateView ();
@@ -151,7 +154,7 @@ namespace Banshee.Sources.Gui
             if (!new_playlist_visible) {
                 return;
             }
-            
+
             if (!parent_was_expanded) {
                 TreeIter iter = store.FindSource (new_playlist_parent);
                 TreePath path = store.GetPath (iter);
@@ -160,10 +163,10 @@ namespace Banshee.Sources.Gui
 
             store.Remove (ref new_playlist_iter);
             new_playlist_visible = false;
-            
+
             UpdateView ();
         }
-        
+
         protected override void OnDragLeave (Gdk.DragContext context, uint time)
         {
             TreePath path;
@@ -173,7 +176,7 @@ namespace Banshee.Sources.Gui
             if (path == null && !TreeIter.Zero.Equals (new_playlist_iter)) {
                 path = store.GetPath (new_playlist_iter);
             }
-            
+
             if (path != null) {
                 final_drag_source = store.GetSource (path);
             }
@@ -182,7 +185,7 @@ namespace Banshee.Sources.Gui
             HideNewPlaylistRow ();
             SetDragDestRow (null, TreeViewDropPosition.Before);
         }
-        
+
         protected override void OnDragBegin (Gdk.DragContext context)
         {
             if (ServiceManager.SourceManager.ActiveSource.SupportedMergeTypes != SourceMergeType.None) {
@@ -204,23 +207,23 @@ namespace Banshee.Sources.Gui
                     Gtk.Drag.Finish (context, false, false, time);
                     return;
                 }
-                
-                Source drop_source = final_drag_source;    
-                
+
+                Source drop_source = final_drag_source;
+
                 if (final_drag_source == NewPlaylistSource) {
-                    PlaylistSource playlist = new PlaylistSource (Catalog.GetString ("New Playlist"), 
+                    PlaylistSource playlist = new PlaylistSource (Catalog.GetString ("New Playlist"),
                         (new_playlist_parent as PrimarySource));
                     playlist.Save ();
                     playlist.PrimarySource.AddChildSource (playlist);
                     drop_source = playlist;
                 }
-                
+
                 if (data.Target.Name == Banshee.Gui.DragDrop.DragDropTarget.Source.Target) {
                     DragDropList<Source> sources = data;
                     if (sources.Count > 0) {
                         drop_source.MergeSourceInput (sources[0], SourceMergeType.Source);
                     }
-                } else if (data.Target.Name == Banshee.Gui.DragDrop.DragDropTarget.UriList.Target) {
+                } else if (data.Target.Name == DragDropTarget.UriList.Target) {
                     foreach (string uri in DragDropUtilities.SplitSelectionData (data)) {
                         // TODO if we dropped onto a playlist, add ourselves
                         // to it after importing (or if already imported, find
@@ -231,7 +234,7 @@ namespace Banshee.Sources.Gui
                     // If the drag source is not the track list, it's a filter list, and instead of
                     // only merging the track model's selected tracks, we should merge all the tracks
                     // currently matching the active filters.
-                    bool from_filter = !(Gtk.Drag.GetSourceWidget (context) is Banshee.Collection.Gui.TrackListView);
+                    bool from_filter = !(Gtk.Drag.GetSourceWidget (context) is Banshee.Collection.Gui.BaseTrackListView);
                     drop_source.MergeSourceInput (
                         ServiceManager.SourceManager.ActiveSource,
                         from_filter ? SourceMergeType.Source : SourceMergeType.ModelSelection
@@ -239,25 +242,25 @@ namespace Banshee.Sources.Gui
                 } else {
                     Hyena.Log.DebugFormat ("SourceView got unknown drag target type: {0}", data.Target.Name);
                 }
-                
+
                 Gtk.Drag.Finish (context, true, false, time);
             } finally {
                 HideNewPlaylistRow ();
             }
         }
-        
+
         protected override void OnDragDataGet (Gdk.DragContext context, SelectionData selectionData,
             uint info, uint time)
         {
             switch ((DragDropTargetType)info) {
                 case DragDropTargetType.Source:
-                    new DragDropList<Source> (ServiceManager.SourceManager.ActiveSource, 
+                    new DragDropList<Source> (ServiceManager.SourceManager.ActiveSource,
                         selectionData, context.Targets[0]);
                     break;
                 default:
                     return;
             }
-            
+
             base.OnDragDataGet (context, selectionData, info, time);
         }
     }
