@@ -62,7 +62,7 @@ namespace Banshee.CoverArt
             // Since we do last_scan - retry_every, avoid out-of-range error by ensuring
             // the last_scan date isn't already MinValue
             if (last_scan == DateTime.MinValue) {
-                last_scan = DateTime.Now - TimeSpan.FromDays (300);
+                last_scan = DateTime.Now - TimeSpan.FromDays (365*50);
             }
 
             CountCommand = new HyenaSqliteCommand (@"
@@ -80,7 +80,7 @@ namespace Banshee.CoverArt
             );
 
             SelectCommand = new HyenaSqliteCommand (@"
-                SELECT DISTINCT CoreAlbums.AlbumID, CoreAlbums.Title, CoreArtists.Name, CoreTracks.Uri
+                SELECT DISTINCT CoreAlbums.AlbumID, CoreAlbums.Title, CoreArtists.Name, CoreTracks.Uri, CoreTracks.TrackID
                     FROM CoreTracks, CoreArtists, CoreAlbums
                     WHERE
                         CoreTracks.PrimarySourceID = ? AND
@@ -90,7 +90,7 @@ namespace Banshee.CoverArt
                         CoreTracks.AlbumID NOT IN (
                             SELECT AlbumID FROM CoverArtDownloads WHERE
                                 LastAttempt > ? OR Downloaded = 1)
-                    GROUP BY CoreTracks.AlbumID LIMIT ?",
+                    GROUP BY CoreTracks.AlbumID ORDER BY CoreTracks.DateUpdatedStamp DESC LIMIT ?",
                 ServiceManager.SourceManager.MusicLibrary.DbId, last_scan, last_scan - retry_every, 1
             );
 
@@ -107,19 +107,25 @@ namespace Banshee.CoverArt
             Register ();
         }
 
+        private class CoverartTrackInfo : DatabaseTrackInfo
+        {
+            public int DbId {
+                set { TrackId = value; }
+            }
+        }
+
         protected override void IterateCore (HyenaDataReader reader)
         {
-            DatabaseTrackInfo track = new DatabaseTrackInfo ();
-
-            track.AlbumTitle = reader.Get<string> (1);
-            track.ArtistName = reader.Get<string> (2);
-            track.PrimarySource = ServiceManager.SourceManager.MusicLibrary;
-            track.Uri = new SafeUri (reader.Get<string> (3));
-            track.AlbumId = reader.Get<int> (0);
-            //Console.WriteLine ("have album {0}/{1} for track uri {2}", track.AlbumId, track.AlbumTitle, track.Uri);
+            var track = new CoverartTrackInfo () {
+                AlbumTitle = reader.Get<string> (1),
+                ArtistName = reader.Get<string> (2),
+                PrimarySource = ServiceManager.SourceManager.MusicLibrary,
+                Uri = new SafeUri (reader.Get<string> (3)),
+                DbId = reader.Get<int> (4),
+                AlbumId = reader.Get<int> (0)
+            };
 
             Status = String.Format (Catalog.GetString ("{0} - {1}"), track.ArtistName, track.AlbumTitle);
-
             FetchForTrack (track);
         }
 
